CreateNamedQueryFluentBuilder

Struct CreateNamedQueryFluentBuilder 

pub struct CreateNamedQueryFluentBuilder { /* private fields */ }
Fluent builder constructing a request to CreateNamedQuery.

Creates a named query in the specified workgroup. Requires that you have access to the workgroup.

Implementations

Source

impl CreateNamedQueryFluentBuilder

pub fn as_input(&self) -> &CreateNamedQueryInputBuilder

Access the CreateNamedQuery as a reference.

pub async fn send( self, ) -> Result<CreateNamedQueryOutput, SdkError<CreateNamedQueryError, HttpResponse>>

Sends the request and returns the response.

If an error occurs, an SdkError will be returned with additional details that can be matched against.

By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.

pub fn customize( self, ) -> CustomizableOperation<CreateNamedQueryOutput, CreateNamedQueryError, Self>

Consumes this builder, creating a customizable operation that can be modified before being sent.

pub fn name(self, input: impl Into<String>) -> Self

The query name.

pub fn set_name(self, input: Option<String>) -> Self

The query name.

pub fn get_name(&self) -> &Option<String>

The query name.

pub fn description(self, input: impl Into<String>) -> Self

The query description.

pub fn set_description(self, input: Option<String>) -> Self

The query description.

pub fn get_description(&self) -> &Option<String>

The query description.

pub fn database(self, input: impl Into<String>) -> Self

The database to which the query belongs.

pub fn set_database(self, input: Option<String>) -> Self

The database to which the query belongs.

pub fn get_database(&self) -> &Option<String>

The database to which the query belongs.

pub fn query_string(self, input: impl Into<String>) -> Self

The contents of the query with all query statements.

pub fn set_query_string(self, input: Option<String>) -> Self

The contents of the query with all query statements.

pub fn get_query_string(&self) -> &Option<String>

The contents of the query with all query statements.

pub fn client_request_token(self, input: impl Into<String>) -> Self

A unique case-sensitive string used to ensure the request to create the query is idempotent (executes only once). If another CreateNamedQuery request is received, the same response is returned and another query is not created. If a parameter has changed, for example, the QueryString, an error is returned.

This token is listed as not required because Amazon Web Services SDKs (for example the Amazon Web Services SDK for Java) auto-generate the token for users. If you are not using the Amazon Web Services SDK or the Amazon Web Services CLI, you must provide this token or the action will fail.

pub fn set_client_request_token(self, input: Option<String>) -> Self

A unique case-sensitive string used to ensure the request to create the query is idempotent (executes only once). If another CreateNamedQuery request is received, the same response is returned and another query is not created. If a parameter has changed, for example, the QueryString, an error is returned.

This token is listed as not required because Amazon Web Services SDKs (for example the Amazon Web Services SDK for Java) auto-generate the token for users. If you are not using the Amazon Web Services SDK or the Amazon Web Services CLI, you must provide this token or the action will fail.

pub fn get_client_request_token(&self) -> &Option<String>

A unique case-sensitive string used to ensure the request to create the query is idempotent (executes only once). If another CreateNamedQuery request is received, the same response is returned and another query is not created. If a parameter has changed, for example, the QueryString, an error is returned.

This token is listed as not required because Amazon Web Services SDKs (for example the Amazon Web Services SDK for Java) auto-generate the token for users. If you are not using the Amazon Web Services SDK or the Amazon Web Services CLI, you must provide this token or the action will fail.

pub fn work_group(self, input: impl Into<String>) -> Self

The name of the workgroup in which the named query is being created.

pub fn set_work_group(self, input: Option<String>) -> Self

The name of the workgroup in which the named query is being created.

pub fn get_work_group(&self) -> &Option<String>

The name of the workgroup in which the named query is being created.